====================
``searching`` module
====================

.. automodule:: whoosh.searching


Searching classes
=================

.. autoclass:: Searcher
    :members:

.. autoclass:: Collector
    :members:
    
.. autoclass:: TermTrackingCollector


Results class
=============

.. autoclass:: Results
    :members:

.. autoclass:: ResultsPage
	:members:



